summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/tools/dcpomatic_kdm.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tools/dcpomatic_kdm.cc b/src/tools/dcpomatic_kdm.cc
index f877ad21f..d60a5e190 100644
--- a/src/tools/dcpomatic_kdm.cc
+++ b/src/tools/dcpomatic_kdm.cc
@@ -280,8 +280,8 @@ private:
);
}
- /** @id if not 0 this is filled in with the wxTreeItemId of the selection */
- shared_ptr<DKDMBase> selected_dkdm (wxTreeItemId* id = 0) const
+ /** @id if not nullptr this is filled in with the wxTreeItemId of the selection */
+ shared_ptr<DKDMBase> selected_dkdm (wxTreeItemId* id = nullptr) const
{
wxArrayTreeItemIds selections;
_dkdm->GetSelections (selections);